#include "xcframe.h"

XCframe_Config XCframe_ConfigTable[] __attribute__ ((section (".drvcfg_sec"))) = {

	{
		"xlnx,pmc-cfi-cframe-11.0", /* compatible */
		0xf12d0000 /* reg */
	},
	 {
		 NULL
	}
};